@@ -1,17 +1,16 @@
 import base64
 import copy
-import importlib.util as util
 import importlib
+import importlib.util as util
 import inspect
 import json
 import multiprocessing
 import os
-import re
 import site
+import socket
 import sqlite3
 import urllib
 import winreg
-import socket
 import xml.etree.ElementTree as ET
 import zlib
 from datetime import datetime, timedelta
@@ -935,6 +934,8 @@ class WorkflowEngine():
                 self.variables.update({'%__time_formatted__%': datetime.now().time().strftime("%H:%M:%S")})
             if str(getattr(step, value)).__contains__("%__now__%"):
                 self.variables.update({'%__now__%': datetime.now()})
+            if str(getattr(step, value)).__contains__("%__now_formatted__%"):
+                self.variables.update({'%__now_formatted__%': datetime.today().date().strftime("%d-%m-%Y") + "_" + datetime.now().time().strftime("%H%M%S")})
             if str(getattr(step, value)).__contains__("%__folder_desktop__%"):
                 self.variables.update({'%__folder_desktop__%': os.path.join(os.path.join(os.environ['USERPROFILE']), 'Desktop')})
             if str(getattr(step, value)).__contains__("%__folder_downloads__%"):
